unit UHtmlTools;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, IpHTML;

type
  THTML_TABLE_ROW = array of string;

  { THTML_AM }

  THTML_AM = class
    private
      FHeader : string;
      FBody : string;
    public
      constructor Create();
      destructor Destroy();override;
      function to_string():string;

      procedure SetHeader(const pcsHTML : string);
      procedure Clear();
      procedure Append(const pcsHTML : string; const pcnTabCount : integer = 0; const pcbNewLine: boolean = True);

      function HTML_Kapsel(const pcsText: string; const pcsTag: string; const pacsParameter : array of string):string;
      function HTML_Liste(const pacsText: array of string; const pcbOrdered: boolean = False):string;
      function HTML_Table(const pacsText: array of THTML_TABLE_ROW): string;
      function HTMLFont(const pcsText: string; const pcnR, pcnG, pcnB, pcnSize: integer):string;
  end;

function EntEumeln(const pcs:string; const pcbNurUmlaute: boolean = True):string;
function LoadTextFromRessource(const pcsRessourceName:string):string;
procedure FillHTML(const pnl: TIpHtmlPanel; const pcsHTML: string);
procedure LoadHTMLFile(const pnl: TIpHtmlPanel; const pcsFileName: string);

implementation

function EntEumeln(const pcs:string; const pcbNurUmlaute: boolean = True):string;
var i: integer;
  c : char;
  s : string;
begin
  result := '';
  for i := 1 to length(pcs) do begin
    c := pcs[i];
    case c of
      #195: s := '';
      #132: s := '&Auml;';
      #150: s := '&Ouml;';
      #156: s := '&Uuml;';
      #164: s := '&auml;';
      #182: s := '&ouml;';
      #188: s := '&uuml;';
      #159: s := '&szlig;';
      '>': if pcbNurUmlaute then s := c else s := '&gt;';
      '<': if pcbNurUmlaute then s := c else s := '&lt;';
    else
      s := c;
    end;
    result := result + s;
  end;
end;

function LoadTextFromRessource(const pcsRessourceName: string): string;
var
  lvRS: TResourceStream;
  lavs: TStringList;
begin
  result := '';
  lavs := TStringList.Create;
  try
    lvRS := TResourceStream.Create(HINSTANCE, pcsRessourceName, 'TEXT');
    try
      lavs.LoadFromStream(lvRS);
      result := lavs.Text;
    finally
      FreeAndNil(lvRS);
    end;
  finally
    FreeAndNil(lavs);
  end;

end;

procedure FillHTML(const pnl: TIpHtmlPanel; const pcsHTML: string);
begin
  pnl.SetHtmlFromStr(pcsHTML);
end;

procedure LoadHTMLFile(const pnl: TIpHtmlPanel; const pcsFileName: string);
var
  lavs: TStringList;
begin
  lavs := TStringList.Create;
  try
    lavs.LoadFromFile(pcsFileName);
    FillHTML(pnl, lavs.Text);
  finally
    FreeAndNil(lavs);
  end;
end;

{ THTML_AM }

constructor THTML_AM.Create();
begin
  FHeader := '';
  FBody := '';
end;

destructor THTML_AM.Destroy();
begin
  inherited Destroy();
end;

function THTML_AM.to_string(): string;
var
  lavs: TStringList;
  i : integer;
begin
  lavs := TStringList.Create;
  try
    result := '<HTML>'#13#10#9'<HEADER>'#13#10;
    lavs.Text := FHeader;
    for i := 0 to lavs.Count - 1 do
      result := result + #9#9 +lavs[i] + #13#10;
    result := result + #9'</HEADER>'#13#10#9'<BODY>'#13#10;
    lavs.Text := FBody;
    for i := 0 to lavs.Count - 1 do
      result := result + #9#9 +lavs[i] + #13#10;
    result := result + #9'</BODY>'#13#10'</HTML>';
  finally
    FreeAndNil(lavs);
  end;
end;

procedure THTML_AM.SetHeader(const pcsHTML: string);
begin
  FHeader := pcsHTML;
end;

procedure THTML_AM.Clear();
begin
  FBody := '';
end;

procedure THTML_AM.Append(const pcsHTML : string; const pcnTabCount : integer = 0; const pcbNewLine: boolean = True);
var
  lavs : TStringList;
  lvsTab, lvsNL : string;
  i : integer;
begin
  lavs := TStringList.Create();
  lvsTab := '';

  for i := 0 to pcnTabCount - 1 do lvsTab := lvsTab + #9;
  try
    lavs.Text := pcsHTML;
    if pcbNewLine or (lavs.Count>1) then
      lvsNL := #13#10
    else
      lvsNL := '';
    for i := 0 to lavs.Count-1 do
      FBody := FBody + lvsTab + lavs[i] + lvsNL;
  finally
    FreeAndNil(lavs);
  end;
end;

function THTML_AM.HTML_Kapsel(const pcsText: string; const pcsTag: string; const pacsParameter: array of string): string;
var
//  lavs: TStringList;
  i : integer;

begin
  //lavs := TStringList.Create();
  result := '';
  for i := 0 to length(pacsParameter) - 1 do
    result := result + ' ' + pacsParameter[i];
  result := trim(result);
  if result > '' then result := ' ' + result;
  result := '<'+pcsTag+result+'>'+pcsText+'</'+pcsTag+'>';
end;

function THTML_AM.HTML_Liste(const pacsText: array of string; const pcbOrdered: boolean): string;
var
  lvs, lvsTag: string;
  i : integer;
begin
  if pcbOrdered then lvsTag := 'OL' else lvsTag := 'UL' ;
  lvs:='';
  for i := 0 to length(pacsText) - 1 do
    lvs := lvs + #9+ HTML_Kapsel(pacsText[i],'LI',[]) + #13#10;
  result := HTML_Kapsel(lvs, lvsTag,[])+#13#10;
end;

function THTML_AM.HTML_Table(const pacsText: array of THTML_TABLE_ROW): string;
begin
  result := '<h1>OCH N&ouml;&ouml;&ouml;&ouml;</h1>';
end;

function THTML_AM.HTMLFont(const pcsText: string; const pcnR, pcnG, pcnB, pcnSize: integer): string;
var
  lvnColor : integer;
  lvsStyle : string;
begin
  //style = "color:%s; font-size:%dpt"
  lvsStyle := '';
  if (0<=pcnR) and (pcnR<256) and (0<=pcnG) and (pcnG<256) and (0<=pcnB) and (pcnB<256) then begin
    lvnColor := ((pcnR * 256) + pcnG) * 256 + pcnB;
    lvsStyle := lvsStyle + Format('color:#%s',[IntToHex(lvnColor,6)]);
  end;
  if (0<=pcnSize) then begin
    if lvsStyle > '' then lvsStyle := lvsStyle + '; ';
    lvsStyle := lvsStyle + Format('font-size:%dpt',[pcnSize]);
  end;
  if lvsStyle > '' then lvsStyle := 'style = "'+lvsStyle+'"';
  result := HTML_Kapsel(pcsText,'font',[lvsStyle]);
end;

end.

